==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/dbquery/loadconnectionsverbose.go <==
package dbquery

import (
	"fmt"
	"strings"

	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"github.com/jmoiron/sqlx"
)

// LoadConnectionsVerbose loads the connections for the given connection IDs
// note, that conn_id incoporates the feed id as a prefix, so passing
// query feedid here is solely for
func LoadConnectionsVerbose(
	DB *sqlx.DB, queryFeedIDs []int, tzToUTCDeltasMap map[string]int, dateYYYYMMDD uint, fromUTCSeconds, toUTCSeconds int,
	connIDs *[]string, fromStopIDs *[]string,
) (*[]dbt.ConnectionVerbose, error) {
	var (
		r      = []dbt.ConnectionVerbose{}
		params = utilfuncs.Flatten([][]any{
			[]any{dateYYYYMMDD, fromUTCSeconds, toUTCSeconds},
			utilfuncs.Anyify(utilfuncs.KeyValues(tzToUTCDeltasMap)),
			utilfuncs.Anyify(queryFeedIDs),
		})
		query string
		err   error
	)

	if query, err = utilfuncs.TemplateExecute(
		query_connections,
		map[string]any{
			"Table":              "_vconnverbose",
			"Columns":            "*",
			"TzToDeltaSubquery":  strings.Join(utilfuncs.ArrayWithValue(len(tzToUTCDeltasMap), "select ? as timezone, ? as seconds"), " union "),
			"FeedIDPlaceholders": strings.Join(utilfuncs.ArrayWithValue(len(queryFeedIDs), "?"), ","),
		},
	); err != nil {
		return nil, err
	}

	// Limit to only passed conn_id's (used for routing api after csa on determined connids)
	if connIDs != nil {
		query = fmt.Sprintf(
			"%s and conn_id in (%s)",
			query, strings.Join(utilfuncs.ArrayWithValue(len(*connIDs), "?"), ","),
		)
		params = append(params, utilfuncs.Anyify(*connIDs)...)
	}
	// Limit to only passed from_stop_sidus (used for stoptimes api)
	if fromStopIDs != nil {
		query = fmt.Sprintf(
			"%s and from_stop_sidu in (%s)",
			query, strings.Join(utilfuncs.ArrayWithValue(len(*fromStopIDs), "?"), ","),
		)
		params = append(params, utilfuncs.Anyify(*fromStopIDs)...)
	}

	if err := queryToSlice(DB, query, params, &r); err != nil {
		return nil, err
	} else {
		return &r, nil
	}
}

==> mobroute-0.9.0.tar.gz: mobroute-v0.9.0/dbquery/loadconnectionsverbose.go <==
package dbquery

import (
	"fmt"
	"strings"

	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"github.com/jmoiron/sqlx"
)

// LoadConnectionsVerbose loads the connections for the given connection IDs
// note, that conn_id incoporates the feed id as a prefix, so passing
// query feedid here is solely for
func LoadConnectionsVerbose(
	DB *sqlx.DB, queryFeedIDs []int, tzToUTCDeltasMap map[string]int, dateYYYYMMDD uint, fromUTCSeconds, toUTCSeconds int,
	connOIDs *[]int, fromStopUIDs *[]string,
) (*[]dbt.ConnectionVerbose, error) {
	var (
		r      = []dbt.ConnectionVerbose{}
		params = utilfuncs.Flatten([][]any{
			[]any{dateYYYYMMDD, fromUTCSeconds, toUTCSeconds},
			utilfuncs.Anyify(utilfuncs.KeyValues(tzToUTCDeltasMap)),
			utilfuncs.Anyify(queryFeedIDs),
		})
		query string
		err   error
	)

	if query, err = utilfuncs.TemplateExecute(
		query_connections,
		map[string]any{
			"Table":              "_vconnverbose",
			"Columns":            "*",
			"TzToDeltaSubquery":  strings.Join(utilfuncs.ArrayWithValue(len(tzToUTCDeltasMap), "select ? as timezone, ? as seconds"), " union "),
			"FeedIDPlaceholders": strings.Join(utilfuncs.ArrayWithValue(len(queryFeedIDs), "?"), ","),
		},
	); err != nil {
		return nil, err
	}

	// Limit to only passed conn_id's (used for routing api after csa on determined connids)
	if connOIDs != nil {
		query = fmt.Sprintf(
			"%s and oid in (%s)",
			query, strings.Join(utilfuncs.ArrayWithValue(len(*connOIDs), "?"), ","),
		)
		params = append(params, utilfuncs.Anyify(*connOIDs)...)
	}
	// Limit to only passed from_stop_parent_uids (used for stoptimes api)
	if fromStopUIDs != nil {
		query = fmt.Sprintf(
			"%s and from_stop_parent_uid in (%s)",
			query, strings.Join(utilfuncs.ArrayWithValue(len(*fromStopUIDs), "?"), ","),
		)
		params = append(params, utilfuncs.Anyify(*fromStopUIDs)...)
	}

	if err := queryToSlice(DB, query, params, &r); err != nil {
		return nil, err
	} else {
		return &r, nil
	}
}
